@@ -59,7 +59,7 @@ ground_interdict(x,y,victim,s)
         for(z=1;z<MAXNOC;z++)
                 initque((struct qelem *)&mi[z]);
 
-        build_mission_list(mi,x,y,MI_INTERDICT);
+        build_mission_list(mi,x,y,MI_INTERDICT,victim);
 
         for(cn=1;cn<MAXNOC;cn++){
                 rel = getrel(getnatp(cn),victim);
@@ -120,7 +120,7 @@ unit_interdict(x,y,victim,s,hardtarget,mission)
 	int	mission;
 {
         register int cn;
-        int     dam=0, newdam, rel;
+        int     dam=0, newdam;
         struct  genlist mi[MAXNOC];
         int     z;
 
@@ -128,11 +128,15 @@ unit_interdict(x,y,victim,s,hardtarget,mission)
         for(z=1;z<MAXNOC;z++)
                 initque((struct qelem *)&mi[z]);
 
-        build_mission_list(mi,x,y,mission);
+        build_mission_list(mi,x,y,mission,victim);
 
         for(cn=1;cn<MAXNOC;cn++){
-                rel = getrel(getnatp(cn),victim);
-                if (rel != AT_WAR)
+		if (cn == victim)
+			continue;
+                if (mission == MI_SINTERDICT) {
+			if (getrel(getnatp(cn),victim) >= FRIENDLY)
+				continue;
+		} else if (getrel(getnatp(cn),victim) != AT_WAR)
                         continue;
 
                 if (QEMPTY(&mi[cn].queue))
@@ -166,8 +170,8 @@ off_support(x,y,victim,actee)
         for(z=1;z<MAXNOC;z++)
                 initque((struct qelem *)&mi[z]);
 
-        build_mission_list(mi,x,y,MI_SUPPORT);
-        build_mission_list(mi,x,y,MI_OSUPPORT);
+        build_mission_list(mi,x,y,MI_SUPPORT,victim);
+        build_mission_list(mi,x,y,MI_OSUPPORT,victim);
 
         dam = dosupport(mi,x,y,victim,actee);
         return dam;
@@ -188,8 +192,8 @@ def_support(x,y,victim,actee)
         for(z=1;z<MAXNOC;z++)
                 initque((struct qelem *)&mi[z]);
 
-        build_mission_list(mi,x,y,MI_SUPPORT);
-        build_mission_list(mi,x,y,MI_DSUPPORT);
+        build_mission_list(mi,x,y,MI_SUPPORT,victim);
+        build_mission_list(mi,x,y,MI_DSUPPORT,victim);
 
         dam = dosupport(mi,x,y,victim,actee);
         return dam;
@@ -221,20 +225,22 @@ dosupport(mi,x,y,victim,actee)
         return dam;
 }
 
-build_mission_list(mi,x,y,mission)
+build_mission_list(mi,x,y,mission,victim)
 	struct  genlist mi[MAXNOC];
 	coord   x,y;
 	int     mission;
+	natid	victim;
 {
-        build_mission_list_type(mi,x,y,mission,EF_LAND);
-        build_mission_list_type(mi,x,y,mission,EF_SHIP);
-        build_mission_list_type(mi,x,y,mission,EF_PLANE);
+        build_mission_list_type(mi,x,y,mission,EF_LAND,victim);
+        build_mission_list_type(mi,x,y,mission,EF_SHIP,victim);
+        build_mission_list_type(mi,x,y,mission,EF_PLANE,victim);
 }
 
-build_mission_list_type(mi,x,y,mission,type)
+build_mission_list_type(mi,x,y,mission,type,victim)
 	struct  genlist mi[MAXNOC];
 	coord   x,y;
 	int     mission,type;
+	natid	victim;
 {
         struct  nstr_item ni;
         struct  genlist *glp;
@@ -244,7 +250,6 @@ build_mission_list_type(mi,x,y,mission,type)
 	int	radius;
 #ifdef SLOW_WAR
         struct  sctstr sect;
-        int     rel;
 #endif /* SLOW_WAR */
 
         size = max(sizeof(struct shpstr),sizeof(struct lndstr));
@@ -274,10 +279,14 @@ build_mission_list_type(mi,x,y,mission,type)
                 if (dist > radius)
                         continue;
 
+		if (mission == MI_SINTERDICT &&
+		    type != EF_PLANE &&
+		    getrel(getnatp(gp->own), victim) > AT_WAR)
+			continue;
 #ifdef SLOW_WAR
-                getsect(x,y,(s_char *)&sect);
-                rel = getrel(getnatp(gp->own), sect.sct_own);
-                if (rel > AT_WAR) {
+		else if (mission != MI_AIR_DEFENSE) {
+			getsect(x,y,(s_char *)&sect);
+			if (getrel(getnatp(gp->own), sect.sct_own) > AT_WAR) {
 
                         /*
                          * If the player->owner of the unit isn't at war
@@ -285,12 +294,12 @@ build_mission_list_type(mi,x,y,mission,type)
                          * sect being acted upon, and isn't the
                          * old player->owner of that sect, bounce them.
                          */
-                        if ((sect.sct_type != SCT_WATER) &&
-                                ((sect.sct_own != gp->own) &&
-                                (sect.sct_oldown != gp->own)) &&
-                                (mission != MI_AIR_DEFENSE))
-                                continue;
-                }
+				if (sect.sct_type != SCT_WATER &&
+				    sect.sct_own != gp->own &&
+				    sect.sct_oldown != gp->own)
+					continue;
+			}
+		}
 #endif /* SLOW_WAR */
 
                 glp = (struct genlist *) malloc(sizeof(struct genlist));
@@ -626,11 +635,11 @@ perform_mission(x,y,victim,list,mission,s,hardtarget)
         find_escorts(x,y,plane_owner,&escorts);
 
         if (mission == MI_SINTERDICT)
-                mission_pln_sel(&bombers,P_T|P_A,0);
+                mission_pln_sel(&bombers,P_T|P_A,0,hardtarget);
         else
-                mission_pln_sel(&bombers,P_T,P_A);
+                mission_pln_sel(&bombers,P_T,P_A,SECT_HARDTARGET);
 
-        mission_pln_sel(&escorts,P_ESC|P_F,0);
+        mission_pln_sel(&escorts,P_ESC|P_F,0,SECT_HARDTARGET);
 
         for(qp = bombers.q_forw; qp != (&bombers); qp = qp->q_forw){
                 plp = (struct plist *)qp;
@@ -658,8 +667,6 @@ perform_mission(x,y,victim,list,mission,s,hardtarget)
                 mission_flags = 0;
                 mission_flags |= P_X;           /* stealth (shhh) */
                 mission_flags |= P_H; /* gets turned off if not all choppers */
-		if (mission == MI_SINTERDICT)
-			mission_flags |= PM_R|P_A;
 
                 mission_flags = mission_pln_arm(&b,air->x,air->y,'p',0,
                         0,mission_flags,&tech);
@@ -672,8 +679,9 @@ perform_mission(x,y,victim,list,mission,s,hardtarget)
                         P_F|P_ESC,mission_flags,&tech);
 
                 bestpath(pp, air->x,air->y,x,y,"");
-                wu(0, air->own, "Flying %s mission\n",
-                        mission_name(mission));
+		if (air->own)
+			wu(0, air->own, "Flying %s mission\n",
+			   mission_name(mission));
 
                 ac_encounter(&b,&e,air->x,air->y,pp,mission_flags,0);
 
@@ -901,10 +909,11 @@ oprange(gp,type,radius)
  *  Remove all planes who cannot go on
  *  the mission from the plane list.
  */
-mission_pln_sel(list, wantflags, nowantflags)
+mission_pln_sel(list, wantflags, nowantflags, hardtarget)
         struct  qelem *list;
         int     wantflags;
         int     nowantflags;
+	int	hardtarget;
 {
         struct  qelem *qp, *next;
         struct  plnstr *pp;
@@ -1050,6 +1059,14 @@ mission_pln_sel(list, wantflags, nowantflags)
                         }
                 }
 
+		if (pcp->pl_flags & P_A) {
+			if (roll(100) > pln_identchance(pp, hardtarget, EF_SHIP)) {
+                                remque(qp);
+                                free((s_char *)qp);
+                                continue;
+			}
+		}				
+
                 putplane(pp->pln_uid, pp);
         }
 }
@@ -1251,6 +1268,7 @@ find_airport(airp,x,y)
         return 0;
 }
 
+/* #*# This needs to be changed to include acc's -KHS */
 add_airport(airp,x,y)
 	struct  qelem *airp;
 	coord   x,y;
@@ -1293,11 +1311,11 @@ divide(l1,l2,x,y)
         }
 }
 
-air_damage(bombers,x,y,mission,hurtee,s,hardtarget)
+air_damage(bombers,x,y,mission,victim,s,hardtarget)
 	struct  qelem *bombers;
 	coord	x,y;
 	int     mission;
-	natid   hurtee;
+	natid   victim;
 	s_char  *s;
 	int	hardtarget;
 {
@@ -1319,40 +1337,60 @@ air_damage(bombers,x,y,mission,hurtee,s,hardtarget)
 			continue;
 
 		newdam = 0;
-		hitchance = pln_hitchance(&plp->plane, hardtarget, EF_SHIP);
-                if ((mission == MI_SINTERDICT) && roll(100) > hitchance) {
-                        wu(0,pp->pln_own,
-			   "\t%s unable to find %s %s\n", prplane(pp),
-			   cname(hurtee), s);
-                        continue;
-                }
+		if (plp->pcp->pl_flags & P_A) {
+			if (roll(100) >  pln_identchance(pp, hardtarget, EF_SHIP)) {
+				wu(0,pp->pln_own,
+				   "\t%s detects sub movement in %s\n",
+				   prplane(pp), xyas(x,y,pp->pln_own));
+				continue;
+			}
+			if (getrel(getnatp(pp->pln_own),victim) > HOSTILE) {
+				wu(0,pp->pln_own,
+				   "\t%s tracks %s %s at %s\n",
+				   prplane(pp),
+				   cname(victim), s, xyas(x,y,pp->pln_own));
+				continue;
+			}
+			wu(0,pp->pln_own,
+			   "\t%s depth-charging %s %s in %s\n",
+			   prplane(pp),
+			   cname(victim),
+			   s,
+			   xyas(x,y,pp->pln_own));
+                } else {
+			wu(0,pp->pln_own,
+			   "\t%s pinbombing %s %s in %s\n",
+			   prplane(pp),
+			   cname(victim),
+			   s,
+			   xyas(x,y,pp->pln_own));
+		}		
+		hitchance = pln_hitchance(pp, hardtarget, EF_SHIP);
 		if (plp->plane.pln_nuketype != -1)
 			hitchance = 100;
 		else if (hardtarget != SECT_HARDTARGET)
-			wu(0,pp->pln_own,"%d%% hitchance...", hitchance);
+			wu(0,pp->pln_own,"\t\t%d%% hitchance...", hitchance);
 		if (roll(100) <= hitchance) {
 			newdam = pln_damage(&plp->plane,x,y,'p',&nukedam);
 			if (nukedam) {
 				if (mission == MI_INTERDICT) {
 					wu(0,pp->pln_own,
-					   "\tnuclear warhead detonated by %s does %d damage to %s %s\n",
+					   "\t\tnuclear warhead does %d damage to %s %s\n",
 					   prplane(pp),
-					   nukedam, cname(hurtee), s);
+					   nukedam, cname(victim), s);
 					dam += nukedam;
 				}
 			} else {
 				wu(0,pp->pln_own,
-				   "\t%s does %d damage to %s %s\n",
-				   prplane(pp),
-				   newdam, cname(hurtee), s);
+				   "\t\thit %s %s for %d damage\n",
+				   cname(victim), s, newdam);
 				dam += newdam;
 			}
 		} else { /* must be ships */
 			wu(0,pp->pln_own,"missed\n");
-			wu(0,pp->pln_own,
-			   "\t%s misses %s %s\n",
-			   prplane(pp),
-			   cname(hurtee), s);
+			mpr(victim,
+			    "RUMBLE... your sub in %s hears a depth-charge explode nearby\n",
+			    xyas(x,y,victim));
 		}
 			
 		/* use up missiles */
@@ -1386,7 +1424,7 @@ air_defense(x,y,victim,bomb_list,esc_list)
         for(z=1;z<MAXNOC;z++)
                 initque((struct qelem *)&mi[z]);
 
-        build_mission_list_type(mi,x,y,MI_AIR_DEFENSE,EF_PLANE);
+        build_mission_list_type(mi,x,y,MI_AIR_DEFENSE,EF_PLANE,victim);
 
         for(cn=1;cn<MAXNOC;cn++){
 
@@ -1422,7 +1460,7 @@ air_defense(x,y,victim,bomb_list,esc_list)
                         insque(&plp->queue, &interceptors);
                 }
 
-                mission_pln_sel(&interceptors,P_F,0);
+                mission_pln_sel(&interceptors,P_F,0,SECT_HARDTARGET);
 
                 if (QEMPTY(&interceptors))
                         continue;
@@ -1460,8 +1498,9 @@ air_defense(x,y,victim,bomb_list,esc_list)
                         }
 
                         bestpath(path, air->x,air->y,x,y,"");
-                        wu(0, air->own, "Flying %s mission\n",
-                                mission_name(MI_AIR_DEFENSE));
+			if (air->own)
+				wu(0, air->own, "Flying %s mission\n",
+				   mission_name(MI_AIR_DEFENSE));
                         initque(&empty);
                         ac_encounter(&i,&empty,air->x,air->y,
                                 path, mission_flags,1);
